<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>افتح</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>فك الربط</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>الرسو</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>إنهاء قسري</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>إغلاق الكل</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation type="unfinished">افتح</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation type="unfinished">فك الربط</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation type="unfinished">الرسو</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation type="unfinished">إنهاء قسري</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation type="unfinished">إغلاق الكل</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
